autop

package
v0.0.0-...-ef2c1a1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 17, 2026 License: GPL-3.0 Imports: 24 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var RootCmd = &cobra.Command{
	Use:           "autop [prompt]",
	Short:         "Run a configured local LLM CLI through one facade",
	SilenceErrors: true,
	SilenceUsage:  true,
	Args:          cobra.ArbitraryArgs,
	RunE:          runRootCommand,
}

RootCmd is the top-level autop command.

var WizardCmd = &cobra.Command{
	Use:     "wizard",
	Aliases: []string{"w"},
	Short:   "Interactively configure an autop PM2 task",
	Args:    cobra.NoArgs,
	RunE:    runWizardCommand,
}

WizardCmd interactively configures an autop PM2 task.

Functions

func CommandExitCode

func CommandExitCode(err error) int

CommandExitCode returns the child process exit code or the generic command error code.

func Execute

func Execute(ctx context.Context) error

Execute loads runtime settings and executes the configured command.

Types

type ClientConfig

type ClientConfig = autopdriver.ClientConfig

type CredentialConfig

type CredentialConfig = autopdriver.CredentialConfig

type PromptTemplate

type PromptTemplate struct {
	Content string `json:"content,omitempty" mapstructure:"content"`
	File    string `json:"file,omitempty" mapstructure:"file"`
}

PromptTemplate is an inline or file-backed Go text template.

type Settings

type Settings struct {
	DefaultClient string                    `json:"default_client" mapstructure:"default_client"`
	Clients       map[string]ClientConfig   `json:"clients" mapstructure:"clients"`
	Templates     map[string]PromptTemplate `json:"templates" mapstructure:"templates"`
}

Settings is the complete runtime configuration for autop.

Directories

Path Synopsis
Package driver maps Autop client profiles to executable process invocations.
Package driver maps Autop client profiles to executable process invocations.

Jump to